@@ -12,8 +12,8 @@ from textblob import TextBlob
 class process_text:
 
     def __init__(self):
-        self.__version__ = "1.5.1"
-        self.nlp = spacy.load("en_core_web_sm")
+        self.__version__ = "2.1.0"
+        self.nlp = spacy.load("en_core_web_md")
         self.path = r".\\TextPreprocessing"
         self.abbreviations = {
             "€" : "euro",
@@ -367,7 +367,7 @@ class process_text:
     
     def clear_generic_entity(self, text):
         document = self.nlp(text)
-        entitites = [ent.text for ent in document.ents if ent.label_ == 'PERSON' or ent.label_ == 'ORDINAL' or ent.label_ == 'DATE']
+        entitites = [ent.text for ent in document.ents if ent.label_ == 'PERSON' or ent.label_ == 'ORDINAL' or ent.label_ == 'CARDINAL' or ent.label_ == 'PRODUCT' or ent.label_ == 'DATE']
         for entity in set(entitites):
             pattern = re.sub("'", "", entity)
             text = re.sub("("+pattern+")", " ", text)
